import { LogLevel } from '@genesislcap/foundation-utils';
export class ErrorBuilder {
    withTitle(title) {
        this.title = title;
        return this;
    }
    withErrorDetails(errorDetails) {
        this.errorDetails = errorDetails;
        return this;
    }
    withLogLevel(logLevel) {
        this.logLevel = logLevel;
        return this;
    }
    withAlert(alert) {
        this.alert = alert;
        return this;
    }
    withNotification(notification) {
        this.notification = notification;
        return this;
    }
    withBanner(banner) {
        this.banner = banner;
        return this;
    }
    withSnackbar(snackbar) {
        this.snackbar = snackbar;
        return this;
    }
    withDialog(dialog) {
        this.dialog = dialog;
        return this;
    }
    build() {
        if (!this.title) {
            throw new Error('Title is required');
        }
        if (!this.errorDetails) {
            throw new Error(`Missing required param 'errorDetails'`);
        }
        let errorStructure = {
            title: this.title,
            errorDetails: this.errorDetails,
        };
        let config = {};
        if (this.logLevel in LogLevel) {
            errorStructure = Object.assign({ logLevel: this.logLevel }, errorStructure);
        }
        if (this.alert) {
            config = Object.assign({ alert: this.alert }, config);
            errorStructure = Object.assign({ config }, errorStructure);
        }
        if (this.notification) {
            config = Object.assign({ notification: this.notification }, config);
            errorStructure = Object.assign({ config }, errorStructure);
        }
        if (this.banner) {
            config = Object.assign({ banner: this.banner }, config);
            errorStructure = Object.assign({ config }, errorStructure);
        }
        if (this.snackbar) {
            config = Object.assign({ snackbar: this.snackbar }, config);
            errorStructure = Object.assign({ config }, errorStructure);
        }
        if (this.dialog) {
            config = Object.assign({ dialog: this.dialog }, config);
            errorStructure = Object.assign({ config }, errorStructure);
        }
        return errorStructure;
    }
}
export const getErrorBuilder = () => new ErrorBuilder();
//# sourceMappingURL=error-builder.js.map