export class SnackbarBuilder {
    /**
     * Add type to snackbar
     * @public
     * @param type
     * @returns
     */
    withType(type) {
        this.type = type;
        return this;
    }
    /**
     * Add confirming action to snackbar
     * @public
     * @param confirmingAction
     * @returns
     * */
    withConfirmingAction(confirmingAction) {
        if (!this.confirmingActions) {
            this.confirmingActions = [];
        }
        this.confirmingActions.push(confirmingAction);
        return this;
    }
    /**
     * Build snackbar
     * @public
     * @returns Snackbar
     * */
    build() {
        let snackbar = {};
        if (this.confirmingActions) {
            snackbar = Object.assign({ confirmingActions: this.confirmingActions }, snackbar);
        }
        if (this.type !== undefined) {
            snackbar = Object.assign({ type: this.type }, snackbar);
        }
        return snackbar;
    }
}
export const getSnackbarBuilder = () => new SnackbarBuilder();
//# sourceMappingURL=snackbar-builder.js.map